PartType

Trait PartType 

pub trait PartType {
    type Ptr;
    type PtrMut;
}
Type of a part, determines what can be done with a part.

Common part types are Field and AbstractPart.

Required Associated Types

type Ptr

Type that can be produced from a constant pointer to a reference target.

type PtrMut

Type that can be produced from a mutable pointer to a reference target.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors