pub unsafe trait SplitIntoParts<'a, ContainingPart, Reference: PartialRef<'a>> {
type Result: PartialRef<'a, Target = Reference::Target>;
type ResultMut: PartialRef<'a, Target = Reference::Target>;
}Expand description
(internal) Split a part into nested parts.
This is used to implement splitting of nested parts.
Required Associated Types
Sourcetype Result: PartialRef<'a, Target = Reference::Target>
type Result: PartialRef<'a, Target = Reference::Target>
A partial reference that has all the parts Reference and all parts of Self nested in
ContainingPart as constant parts.
Sourcetype ResultMut: PartialRef<'a, Target = Reference::Target>
type ResultMut: PartialRef<'a, Target = Reference::Target>
A partial reference that has all the parts Reference and all parts of Self nested in
ContainingPart as mutable parts.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".